@@ -1,7 +1,7 @@
 <?php
 
 /**
- * Github Issue:    https://github.com/ejmr/php-mode/issues/18
+ * Github Issue:    https://github.com/emacs-php/php-mode/issues/18
  *
  * If we run indent-region on the code below then it should appear
  * like so:
@@ -9,7 +9,7 @@
  * $a = 'github';
  *
  * if ($a === 'github') {
- *     header('Location: http://github.com');
+ *     header('Location: https://github.com');
  * }
  *
  * This tests for a bug where '//' inside of a string would cause an
@@ -19,5 +19,5 @@
 $a = 'github';
 
 if ($a === 'github') {
-    header('Location: http://github.com'); // ###php-mode-test### ((indent c-basic-offset))
-}
\ No newline at end of file
+    header('Location: https://github.com'); // ###php-mode-test### ((indent c-basic-offset))
+}
